//
//  SplitViews.java
//  Termites
//
//  Created by John Montgomery on Fri Feb 06 2004.
//  Copyright (c) 2004 Little Spikey Land. All rights reserved.
//

import javax.swing.*;

/** A simple class that makes two TermiteViews (one overhead, one sideon)
 *  and puts them side to side, with a control in the middle to alter their 
 *  relative sizes.
 **/
public class SplitViews extends JSplitPane {
    private TermiteView overheadView = null;
    private TermiteView sideView     = null;
    private TermiteSim  sim          = null;
    
    public SplitViews() {
        overheadView = new TermiteView( true );
        sideView     = new TermiteView( false );
        add( overheadView, JSplitPane.LEFT );
        add( sideView, JSplitPane.RIGHT );
        setResizeWeight( 0.5 );
    }
    
	/** Set the sim to be viewed by both views.
	 **/
    public void setTermiteSim( TermiteSim sim ) {
        this.sim = sim;
        overheadView.setTermiteSim( sim );
        sideView.setTermiteSim( sim );
    }

	/** Specify whether termites will be drawn in both
	 *  views or not.
	 **/
    public void setShowTermites( boolean showTermites ) {
        overheadView.setShowTermites( showTermites );
        sideView.setShowTermites( showTermites );
    }
    
	/** Specify whether to show pheremones in both views
	 *  or not.
	 **/
    public void setShowPheremones( boolean showPheremones ) {
        overheadView.setShowPheremones( showPheremones );
        sideView.setShowPheremones( showPheremones );
    }


}
